==> ejc-scientific-api-3.0.0-20250307.095914-46-sources.jar: com/ejianc/business/scientific/sci/vo/SciProjectChangeBudgetVO.java <==
package com.ejianc.business.scientific.sci.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 科研项目立项-变更-经费预算
 * 
 * @author generator
 * 
 */
public class SciProjectChangeBudgetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private Long feeId; // 费用类型主键
    private String feeName; // 费用类型名称
    private BigDecimal budgetMny; // 预算金额
    private String memo; // 备注
    private Long sourceId; // 来源主键
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeeId() {
        return feeId;
    }

    @ReferDeserialTransfer
    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }

    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-scientific-api-3.0.0-20250901.130824-93-sources.jar: com/ejianc/business/scientific/sci/vo/SciProjectChangeBudgetVO.java <==
package com.ejianc.business.scientific.sci.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 科研项目立项-变更-经费预算
 * 
 * @author generator
 * 
 */
public class SciProjectChangeBudgetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private Long feeId; // 费用类型主键
    private String feeName; // 费用类型名称
    private BigDecimal budgetMny; // 预算金额
    private String memo; // 备注
    private Long sourceId; // 来源主键

    private List<SciProjectChangeBudgetYearVO> yearList = new ArrayList<>(); // 科研项目立项-变更-经费预算-年度预算

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeeId() {
        return feeId;
    }

    @ReferDeserialTransfer
    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }

    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public List<SciProjectChangeBudgetYearVO> getYearList() {
        return yearList;
    }

    public void setYearList(List<SciProjectChangeBudgetYearVO> yearList) {
        this.yearList = yearList;
    }
}
